@@ -41,7 +41,7 @@ describe('removeDirectivesFromDocument', () => {
         field
       }
     `;
-    const test = ({ name: { value } }: { name: any }) => value === 'storage';
+    const test = ({ name: { value } }) => value === 'storage';
     const doc = removeDirectivesFromDocument([{ test }], query);
     expect(print(doc)).toBe(print(expected));
   });
@@ -77,7 +77,7 @@ describe('removeDirectivesFromDocument', () => {
         field
       }
     `;
-    const test = ({ name: { value } }: { name: any }) => value === 'storage';
+    const test = ({ name: { value } }) => value === 'storage';
     const doc = removeDirectivesFromDocument([{ test }], query);
     expect(print(doc)).toBe(print(expected));
   });
@@ -118,7 +118,7 @@ describe('removeDirectivesFromDocument', () => {
     const removed = [
       { name: 'storage' },
       {
-        test: (directive: any) => directive.name.value === 'client',
+        test: directive => directive.name.value === 'client',
       },
     ];
     const doc = removeDirectivesFromDocument(removed, query);
@@ -156,7 +156,7 @@ describe('removeDirectivesFromDocument', () => {
         keep
       }
     `;
-    const test = ({ name: { value } }: { name: any }) => value === 'storage';
+    const test = ({ name: { value } }) => value === 'storage';
     const doc = removeDirectivesFromDocument([{ test, remove: true }], query);
     expect(print(doc)).toBe(print(expected));
   });
@@ -181,7 +181,7 @@ describe('removeDirectivesFromDocument', () => {
       }
     `;
 
-    const test = ({ name: { value } }: { name: any }) => value === 'storage';
+    const test = ({ name: { value } }) => value === 'storage';
     const doc = removeDirectivesFromDocument([{ test, remove: true }], query);
     expect(doc).toBe(null);
   });
@@ -312,6 +312,21 @@ describe('query transforms', () => {
 
     expect(expectedQueryStr).toBe(print(newQueryDoc));
   });
+  it('should memoize and return cached results', () => {
+    let testQuery = gql`
+      query {
+        author {
+          name {
+            firstName
+            lastName
+          }
+        }
+      }
+    `;
+    const newQueryDoc = addTypenameToDocument(testQuery);
+    const secondCall = addTypenameToDocument(testQuery);
+    expect(newQueryDoc).toBe(secondCall);
+  });
 
   it('should not add duplicates', () => {
     let testQuery = gql`
@@ -552,6 +567,21 @@ describe('query transforms', () => {
 
     expect(expectedQueryStr).toBe(print(newQueryDoc));
   });
+  it('should memoize and return cached results', () => {
+    let testQuery = gql`
+      query {
+        author {
+          name @connection(key: "foo") {
+            firstName
+            lastName
+          }
+        }
+      }
+    `;
+    const newQueryDoc = removeConnectionDirectiveFromDocument(testQuery);
+    const secondCall = removeConnectionDirectiveFromDocument(testQuery);
+    expect(newQueryDoc).toBe(secondCall);
+  });
 });
 
 describe('getDirectivesFromDocument', () => {
@@ -583,7 +613,7 @@ describe('getDirectivesFromDocument', () => {
         field @storage(if: true)
       }
     `;
-    const test = ({ name: { value } }: { name: any }) => value === 'storage';
+    const test = ({ name: { value } }) => value === 'storage';
     const doc = getDirectivesFromDocument([{ test }], query);
     expect(print(doc)).toBe(print(expected));
   });
@@ -952,5 +982,4 @@ describe('getDirectivesFromDocument', () => {
       const doc = getDirectivesFromDocument([{ name: 'client' }], query, true);
       expect(print(doc)).toBe(print(expected));
     });
-  });
 });
